/*!
  @header ECXMLControlState
  @abstract Module of Encore
 
  @availability OS X, GNUstep
  @copyright 2004, 2005, 2006 Oliver Langer

  Author: Oliver Langer

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA

  <pre>
  -------------------------------------------------------------------------
  Modification history

  27.11.05 ola     initial version
  22.08.06 ola     license changed
  -------------------------------------------------------------------------
  </pre>
*/

#include <ECXMLControlState.h>

@implementation ECXMLControlState
- init {
  self = [super init];
  self->userObjectStack = [[ECStack alloc] init];
  self->allUserObjects = [[NSMutableArray alloc] init];
  self->globalRuleData = [[NSMutableDictionary alloc] init];
  
  return self;
}


- (void) dealloc {
  if( nil != self->userObjectStack ) {
    [self->userObjectStack release];
  }
  
  if( nil != self->allUserObjects ) {
    [self->allUserObjects release];
  }
  
  [self->globalRuleData release];
  
  [super dealloc];
}


- (NSArray *) allUserObjects {
  return self->allUserObjects;
}


- (unsigned) countStackObjects {
  return [self->userObjectStack count];
}


- (NSMutableDictionary *)  globalRuleData {
  return self->globalRuleData;
}


- popUserObject {
  return [self->userObjectStack popObject];
}


- pushUserObject: (id) aUserObject {
  [self->userObjectStack pushObject: aUserObject];
  [self->allUserObjects addObject: aUserObject];
  return self;
}


- userObjectAtTopPosition {
  return [self->userObjectStack topObject];
}
@end
